# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/custom/new/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/custom/new/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Custom\\New\\": "packages/custom/new/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Custom\New\Providers\NewServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'New'  => Custom\New\Facades\New::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Custom\\NewTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Custom\New\Providers\NewServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Custom\New\Providers\NewServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Custom\New\Providers\NewServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/new/{modulename}

**User**

    http://path-to-route-folder/user/new/{modulename}

**Public**

    http://path-to-route-folder/news


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/new/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/new/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/new/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/new/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/new/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/new/{modulename}/{slug}
    METHOD: GET